##  Configuring Fact Sheet Permissions
Follow these steps:
  1. On the Meta Model Configuration page, select a fact sheet for which you want to configure permissions.
  2. On the fact sheet configuration page, navigate to the Permissions tab.
  3. In the Permission Role list, select a role.
  4. Adjust permissions as needed, then save the changes.
![Configuring Fact Sheet Permissions](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod63f73c84d05404296e0a5b4852564e0_LowRes.png)
Configuring Fact Sheet Permissions for the Viewer Role
